@@ -553,6 +553,20 @@ class TestDTLSConfiguration:
         assert_conf_invariant(conf, handshake_timeout_min=hs_min)
         assert_conf_invariant(conf, handshake_timeout_max=hs_max)
 
+    @pytest.mark.parametrize("timeout", [1, 10, 5.3, 300])
+    def test_read_timeout_default(
+        self,
+        conf: Union[TLSConfiguration, DTLSConfiguration],
+        timeout: float,
+    ) -> None:
+        assert conf.read_timeout == 0
+        conf_ = conf.update(
+            read_timeout=timeout,
+        )
+        assert conf_.read_timeout == timeout
+
+        assert_conf_invariant(conf, read_timeout=timeout)
+
 
 class TestContext:
     @pytest.fixture(params=[Purpose.SERVER_AUTH, Purpose.CLIENT_AUTH])
